@@ -29,7 +29,6 @@
 
 #include "irplib_framelist.h"
 #include "irplib_utils.h"
-#include <cpl.h>
 
 #include <stdio.h>
 #include <string.h>
@@ -200,10 +199,8 @@ void irplib_framelist_delete(irplib_framelist * self)
 /*----------------------------------------------------------------------------*/
 irplib_framelist * irplib_framelist_cast(const cpl_frameset * frameset)
 {
-
     irplib_framelist * self;
-    int i;
-
+    int i ;
 
     cpl_ensure(frameset != NULL, CPL_ERROR_NULL_INPUT, NULL);
 
@@ -216,7 +213,10 @@ irplib_framelist * irplib_framelist_cast(const cpl_frameset * frameset)
 
         cpl_frame * copy = cpl_frame_duplicate(frame);
 
-        const cpl_error_code error = irplib_framelist_set(self, copy, i);
+#ifndef NDEBUG
+        const cpl_error_code error =
+#endif
+            irplib_framelist_set(self, copy, i);
 
         assert(error == CPL_ERROR_NONE);
 
@@ -241,9 +241,8 @@ irplib_framelist * irplib_framelist_cast(const cpl_frameset * frameset)
 /*----------------------------------------------------------------------------*/
 cpl_frameset * irplib_frameset_cast(const irplib_framelist * self)
 {
-
     cpl_frameset * new;
-    int i;
+    int i ;
 
     cpl_ensure(self != NULL, CPL_ERROR_NULL_INPUT, NULL);
 
@@ -252,7 +251,10 @@ cpl_frameset * irplib_frameset_cast(const irplib_framelist * self)
 
     for (i = 0; i < self->size; i++) {
         cpl_frame * frame = cpl_frame_duplicate(self->frame[i]);
-        const cpl_error_code error = cpl_frameset_insert(new, frame);
+#ifndef NDEBUG
+        const cpl_error_code error =
+#endif
+            cpl_frameset_insert(new, frame);
 
         assert(error == CPL_ERROR_NONE);
 
@@ -296,20 +298,21 @@ irplib_framelist * irplib_framelist_extract(const irplib_framelist * self,
         const cpl_frame * frame = self->frame[i];
         const char * ftag = cpl_frame_get_tag(frame);
         cpl_frame * copy;
-        cpl_error_code error;
+        cpl_error_code code;
 
         if (ftag == NULL) {
             /* The frame is ill-formed */
             irplib_framelist_delete(new);
-            cpl_ensure(0, CPL_ERROR_ILLEGAL_INPUT, NULL);
+            (void)cpl_error_set(cpl_func, CPL_ERROR_ILLEGAL_INPUT);
+            return NULL;
         }
 
         if (strcmp(tag, ftag)) continue;
 
         copy = cpl_frame_duplicate(frame);
 
-        error = irplib_framelist_set(new, copy, newsize);
-        assert(error == CPL_ERROR_NONE);
+        code = irplib_framelist_set(new, copy, newsize);
+        if (code != CPL_ERROR_NONE) break; /* Should not be possible */
 
         if (self->propertylist[i] != NULL) new->propertylist[newsize]
             = cpl_propertylist_duplicate(self->propertylist[i]);
@@ -620,7 +623,7 @@ cpl_error_code irplib_framelist_load_propertylist(irplib_framelist * self,
   @param    invert Boolean to invert the sense of the pattern matching.
   @return   CPL_ERROR_NONE or the relevant CPL error code
   @see      irplib_framelist_load_propertylist()
-  @note     Use a regexp of "" to load all properties. If a frame already has
+  @note     Use a regexp of ".?" to load all properties. If a frame already has
             a propertylist, it is not modified (and no propertylist is loaded
             for that frame).
 
@@ -902,8 +905,8 @@ cpl_error_code irplib_framelist_contains(const irplib_framelist * self,
                                          cpl_boolean is_equal, double fp_tol)
 {
 
-    char * value_0;
-    char * value_i;
+    char * value_0 = NULL;
+    char * value_i = NULL;
     cpl_type type_0 = CPL_TYPE_INVALID;
     int i, ifirst = -1;  /* First non-NULL propertylist */
 
@@ -1059,7 +1062,7 @@ cpl_imagelist * irplib_imagelist_load_framelist(const irplib_framelist * self,
 
     for (i=0; i < self->size; i++, image = NULL) {
         const char * filename = cpl_frame_get_filename(self->frame[i]);
-        cpl_error_code error;
+        cpl_error_code code;
 
         if (filename == NULL) break;
 
@@ -1077,8 +1080,8 @@ cpl_imagelist * irplib_imagelist_load_framelist(const irplib_framelist * self,
             break;
         }
 
-        error = cpl_imagelist_set(list, image, i);
-        assert(error == CPL_ERROR_NONE);
+        code = cpl_imagelist_set(list, image, i);
+        if (code != CPL_ERROR_NONE) break; /* Should not be possible */
     }
 
     cpl_image_delete(image);
@@ -1086,7 +1089,7 @@ cpl_imagelist * irplib_imagelist_load_framelist(const irplib_framelist * self,
     if (cpl_imagelist_get_size(list) != self->size) {
         cpl_imagelist_delete(list);
         list = NULL;
-        assert(cpl_error_get_code() != CPL_ERROR_NONE);
+        (void)cpl_error_set_where(cpl_func);
     }
 
     return list;
@@ -1122,13 +1125,15 @@ static void irplib_framelist_set_size(irplib_framelist * self)
         cpl_free(self->propertylist);
         self->frame = NULL;
         self->propertylist = NULL;
-    } else {
+    } else if (self->size > 0) {
         /* Update the size of the arrays */
 
-        self->frame = cpl_realloc(self->frame, self->size * sizeof(cpl_frame*));
+        self->frame = cpl_realloc(self->frame, (size_t)self->size * sizeof(cpl_frame*));
         self->propertylist =
-            cpl_realloc(self->propertylist,
-                        self->size * sizeof(cpl_propertylist*));
+                        cpl_realloc(self->propertylist,
+                                        (size_t)self->size * sizeof(cpl_propertylist*));
+    } else {
+        (void)cpl_error_set(cpl_func, CPL_ERROR_ILLEGAL_INPUT);
     }
 
 }
@@ -1266,10 +1271,11 @@ static cpl_boolean irplib_property_equal(const cpl_propertylist * self,
     }
     default:
         /* Unknown property type */
+#ifdef NDEBUG
+        equal = CPL_FALSE;
+#endif
         assert( 0 );
 
-        equal = CPL_FALSE; /* In case of -DNDEBUG */
-
     }
 
     if (!equal) {
