@@ -463,7 +463,7 @@ static void xsh_orderpos(cpl_parameterlist* parameters,
 					      instrument, &resid_tab ),
 	     "Error in xsh_detect_continuum, try to increase detectcontinuum-fit-win-hsize or detectcontinuum-ordertab-deg-y or detectcontinuum-clip-sigma or detectcontinuum-search-win-hsize" ) ;
   /* monitor input frame flux */
-  check(xsh_monitor_flux( intFrame, resFrame, instrument));
+  check(xsh_monitor_flux( intFrame, resFrame, instrument, XSH_QC_FLUX));
   /**************************************************************************/
   /* Products */
   /**************************************************************************/
