@@ -521,20 +521,47 @@ static cpl_error_code
      * 2x2 std 1x1 mflat,mbias --> correct bin of mflat,mbias
      *
      */
-    check(xsh_frameset_uniform_bin(&raws, &calib,instrument));
+    //check(xsh_frameset_uniform_bin(&raws, &calib,instrument));
 
 
   /**************************************************************************/
   /* Recipe frames */
   /**************************************************************************/
+    /*
   check(xsh_slit_offset_get_calibs(calib,instrument,&bpmap,&master_bias,
                                    &master_dark,&order_tab_edges,
                                    &model_config_frame,&wave_tab,&master_flat,
                                    &wavemap,&slitmap,&spectral_format,RECIPE_ID));
+*/
+    {
 
 
+    	xsh_get_normal_calibs(calib, instrument, RECIPE_ID, pre_overscan_corr,
+    			&spectral_format, &master_bias, &bpmap, &order_tab_edges,
+				&master_flat);
+
+    	/* TODO: Is mdark input really needed? */
+    	if((master_dark=xsh_find_frame_with_tag(calib,XSH_MASTER_DARK,
+    			instrument))==NULL){
+    		xsh_error_reset();
+    	}
+
+    	//The following need to be defined
+    	int do_computemap=1;
+    	xsh_get_dispersion_calibs(calib, instrument, do_computemap,
+    			&model_config_frame,&wave_tab, &wavemap);
+    	//The following is also present in xsh_get_dispersion_calibs
+    	check( wavemap = xsh_find_wavemap( calib, instrument));
+    	//The following should be removed to xsh_get_dispersion_calibs
+    	check( slitmap = xsh_find_slitmap( calib, instrument));
+
+
+
+    }
+
   /* QC extra frames */
-  resp_fit_points_cat_frame=xsh_find_frame_with_tag(calib,XSH_RESP_FIT_POINTS_CAT,instrument);
+  resp_fit_points_cat_frame=xsh_find_frame_with_tag(calib,
+		  XSH_RESP_FIT_POINTS_CAT,instrument);
   if(resp_fit_points_cat_frame==NULL) {
      xsh_msg_warning("Missing input %s_%s response will not be computed",
                      XSH_RESP_FIT_POINTS_CAT,
@@ -553,7 +580,6 @@ static cpl_error_code
      xsh_msg_error("Provide std star catalog frame");
      return CPL_ERROR_DATA_NOT_FOUND;
   }
-  //high_abs_win=xsh_find_frame_with_tag(calib,XSH_HIGH_ABS_WIN,instrument);
   tell_mod_cat=xsh_find_frame_with_tag(calib,XSH_TELL_MOD_CAT,instrument);
 
   /* to compute efficiency */
@@ -668,6 +694,7 @@ static cpl_error_code
      }
 
      sprintf(sky_tag,"%s%s%s",rec_prefix,"_SKY_",arm_str);
+     check(xsh_frameset_uniform_bin(&sky_dark, &calib,instrument));
      check(avg_sky=xsh_frameset_average_pre(sky_dark,instrument,sky_tag));
      if(do_flatfield==1) {
         sprintf(sky_tag,"%s%s%s",rec_prefix,"_FF_SKY_",arm_str);
@@ -694,7 +721,7 @@ static cpl_error_code
 
     xsh_pre_free( &xpre ) ;
   }
-
+  check(xsh_frameset_uniform_bin(&sub_frameset, &calib,instrument));
   if (do_flatfield == 1) {
     clean_frameset=xsh_frameset_mflat_divide(sub_frameset,master_flat,instrument);
   } else {
