@@ -441,11 +441,11 @@ static void xsh_scired_ifu_stare(cpl_parameterlist* parameters,
 				  cpl_frameset* frameset)
 {
 
-  const char* recipe_tags[3] = {XSH_OBJECT_IFU_STARE,
+  const char* recipe_tags[4] = {XSH_OBJECT_IFU_STARE,XSH_SKY_IFU,
                                 XSH_STD_TELL_IFU_STARE,
                                 XSH_STD_FLUX_IFU_STARE};
 
-  int recipe_tags_size = 3;
+  int recipe_tags_size = 4;
 
   /* Input frames */
   cpl_frameset *raws = NULL;
