@@ -505,7 +505,7 @@ int main( int argc, char **argv)
 
     sprintf( tag, "COMBINE_NOD%d", i);
     check( combine_nod_frame = xsh_combine_nod( combine_set, &cnod_par, 
-      tag, instrument, &combine_nodeso_frame));
+      tag, instrument, &combine_nodeso_frame,0));
     check( analyse_rectify( combine_nod_frame, inod, instrument));
   
     xsh_free_frameset( &combine_set);
@@ -514,7 +514,7 @@ int main( int argc, char **argv)
   }
 
   check( combine_nod_frame = xsh_combine_nod( nod_set, &cnod_par,
-      "FULL_COMBINE_NOD", instrument,&combine_nodeso_frame));
+      "FULL_COMBINE_NOD", instrument,&combine_nodeso_frame,0));
     check( analyse_rectify( combine_nod_frame, inod, instrument));
 
   cleanup:
