@@ -264,6 +264,10 @@ cpl_propertylist * mkHeader( XSH_INSTRCONFIG *iconfig,
              "Cant append BINX" ) ;
   check_msg( cpl_propertylist_append_int( header, XSH_WIN_BINY,1 ),
              "Cant append BINY" ) ;
+  check_msg( cpl_propertylist_append_string( header, XSH_DPR_CATG, "CALIB" ),
+                "Cant append DPR CATG" ) ;
+    check_msg( cpl_propertylist_append_string( header, XSH_DPR_TYPE, "DUMMY" ),
+                  "Cant append DPR TYPE" ) ;
   return header ;
  cleanup:
   return NULL ;
@@ -324,6 +328,10 @@ void setHeader( cpl_propertylist * header, XSH_INSTRCONFIG *iconfig,
   check_msg( cpl_propertylist_append_double( header, XSH_CONAD,
                                              iconfig->conad ) ,
              "Cant append CONAD" ) ;
+  check_msg( cpl_propertylist_append_string( header, XSH_DPR_CATG, "CALIB" ),
+              "Cant append DPR CATG" ) ;
+  check_msg( cpl_propertylist_append_string( header, XSH_DPR_TYPE, "DUMMY" ),
+                "Cant append DPR TYPE" ) ;
   /* Special NIR */
   if ( iconfig->bitpix == 32){
     check_msg( cpl_propertylist_append_double( header, XSH_DET_PXSPACE,
