@@ -71,21 +71,23 @@
 #define QFLAG_CAMERA_DEFECT 0x2000
 #define QFLAG_OTHER_BAD_PIXEL 0x4000
   /* Room for user defined bad pixel codes */
-#define QFLAG_NON_LINEAR_PIXEL 0x8000 /* 2e16 => 32768 */
-#define QFLAG_NON_SPATIAL_UNIFORMITY 0x10000
-#define QFLAG_DIVISOR_ZERO 0x20000
-#define QFLAG_OUT_OF_NOD   0x40000 /* Not in rectified shifted frame */
+#define QFLAG_NON_LINEAR_PIXEL 0x8000         /* 2e16 =>  32 768 */
+#define QFLAG_NON_SPATIAL_UNIFORMITY 0x10000  /* 2e17     65 536 */
+#define QFLAG_DIVISOR_ZERO 0x20000            /* 2e18    131 072 */
+#define QFLAG_OUT_OF_NOD   0x40000            /* 2e19    262 144 */
+/*Not in rectified shifted frame */
 /* ... */
-#define QFLAG_MISSING_DATA 0x80000 /* 2e19 */
-#define QFLAG_SATURATED_DATA 0x100000 /* 2e20 */
-#define QFLAG_NEGATIVE_DATA 0x200000 /* 2e21 */
-#define QFLAG_INTERPOL_FLUX 0x400000 /* 2e22 */
-#define QFLAG_SKY_MODEL_BAD_FIT 0x800000 /* 2e23 */
-#define QFLAG_SKY_MODEL_BAD_PIX 0x1000000 /* 2e24 */
-#define QFLAG_ALL_PIX_BAD 0x2000000 /* 2e25 */
-#define QFLAG_INCOMPLETE_DATA 0x4000000 /* 2e26 */
-
-#define QFLAG_OUTSIDE_DATA_RANGE 0x40000000 /* 2e30 */
+#define QFLAG_MISSING_DATA 0x80000          /* 2e19       524 288 */
+#define QFLAG_SATURATED_DATA 0x100000       /* 2e20     1 048 576 */
+#define QFLAG_NEGATIVE_DATA 0x200000        /* 2e21     2 097 152 */
+#define QFLAG_INTERPOL_FLUX 0x400000        /* 2e22     4 194 304 */
+#define QFLAG_SKY_MODEL_BAD_FIT 0x800000    /* 2e23     8 388 608 */
+#define QFLAG_SKY_MODEL_BAD_PIX 0x1000000   /* 2e24    16 777 216 */
+#define QFLAG_ALL_PIX_BAD 0x2000000         /* 2e25    33 554 432 */
+#define QFLAG_INCOMPLETE_DATA 0x4000000     /* 2e26    67 108 864 */
+#define QFLAG_INCOMPLETE_NOD 0x8000000      /* 2e27   134 217 728 */
+#define QFLAG_SCALED_NOD 0x10000000         /* 2e28   268 435 456 */
+#define QFLAG_OUTSIDE_DATA_RANGE 0x40000000 /* 2e30 1 073 741 824 */
     /*} PIXEL_QUALITY_FLAG ; */
 
 /*------------------------------------------------------------------------
@@ -99,7 +101,8 @@ void xsh_bpmap_set_bad_pixel( cpl_image * bpmap, int ix, int iy,
 void xsh_bpmap_mask_bad_pixel(cpl_image * bpmap, cpl_mask* mask,
   int flag ) ;
 cpl_mask* xsh_qual_to_cpl_mask(cpl_image * qual, const int decode_bp);
-
+cpl_mask*
+xsh_code_is_in_qual(cpl_image * qual, const int code) ;
 cpl_frame*
 xsh_badpixelmap_crea_master_from_bpmap(cpl_frame* bpmap, xsh_instrument* inst);
 
@@ -163,7 +166,8 @@ cpl_error_code
 xsh_image_clean_mask_pixs(cpl_image** ima,cpl_image* msk,const int r);
 cpl_image* xsh_image_flag_bptype_with_crox(cpl_image* ima);
 cpl_error_code
-xsh_badpixelmap_flag_saturated_pixels(xsh_pre* pre,xsh_instrument* instr,const double cor_val, int flag, int* nsat);
+xsh_badpixelmap_flag_saturated_pixels(xsh_pre* pre,xsh_instrument* instr,
+		const double cor_val, const int flag, const int is_flat, int* nsat);
 cpl_error_code
 xsh_badpixelmap_fill_bp_pattern_holes(cpl_frame* frm);
 cpl_error_code
