@@ -307,6 +307,9 @@ xsh_mdark_measure_fpn(xsh_pre* preFrame,cpl_parameterlist* parameters,xsh_instru
   check(fpn_lly=xsh_parameters_get_int(parameters,"xsh_mdark","fpn_lly"));
   check(fpn_urx=xsh_parameters_get_int(parameters,"xsh_mdark","fpn_urx"));
   check(fpn_ury=xsh_parameters_get_int(parameters,"xsh_mdark","fpn_ury"));
+  //check(fpn_nsamp=xsh_parameters_get_int(parameters,"xsh_mdark","fpn_nsamples"));
+  //check(fpn_hsize=xsh_parameters_get_int(parameters,"xsh_mdark","fpn_hsize"));
+  //xsh_msg("fpn=%d %d %d %d",fpn_llx,fpn_lly,fpn_urx,fpn_ury);
   sx=cpl_image_get_size_x(preFrame->data);
   sy=cpl_image_get_size_y(preFrame->data);
 
@@ -335,7 +338,10 @@ xsh_mdark_measure_fpn(xsh_pre* preFrame,cpl_parameterlist* parameters,xsh_instru
   zone_fpn[2]=fpn_lly;
   zone_fpn[3]=fpn_ury;
   xsh_image_flag_bp(preFrame->data,preFrame->qual,instrument);
-
+  /*
+  xsh_msg("fpn=%d %d %d %d hsize=%d nsamp=%d",fpn_llx,fpn_urx,fpn_lly,fpn_ury,
+  	  fpn_hsize,fpn_nsamp);
+  	  */
   check_msg(cpl_flux_get_noise_window(preFrame->data, zone_fpn, fpn_hsize,
               fpn_nsamp, &qc_fpn_val, &qc_fpn_err),
       "Error computing noise in a window");
