@@ -1824,8 +1824,8 @@ void xsh_pre_divide (xsh_pre* self, const xsh_pre * right, const int is_flat, do
       */
       qual1[i] |= qual2[i];
       if ( (is_flat) &&
-    	   (qual2[i] & QFLAG_SATURATED_DATA > 0 ) &&
-		   (qual1[i] & QFLAG_SATURATED_DATA == 0 )
+    	   (qual2[i] & (QFLAG_SATURATED_DATA > 0) ) &&
+		   (qual1[i] & (QFLAG_SATURATED_DATA == 0) )
           ) {
     	  /* if division was by a saturated flat remove
     	   * saturated pixel quality
