@@ -118,12 +118,13 @@ xsh_detmon_rm_bpixs(cpl_image **,
 /* The following 2 functions are duplicated from cpl_det */
 
 
-
+#if 0
 static cpl_bivector    *
 irplib_bivector_gen_rect_poisson(const int *r,
                                  const int np,
                                  const int homog);
 
+
 static cpl_error_code
 xsh_detmon_dark_save(const cpl_parameterlist *,
                  cpl_frameset *,
@@ -147,7 +148,7 @@ static cpl_error_code
 xsh_detmon_retrieve_dark_params(const char *,
                             const char *,
                             const cpl_parameterlist *);
-
+#endif
 
 /*---------------------------------------------------------------------------*/
 
@@ -413,7 +414,8 @@ xsh_detmon_rm_bpixs(cpl_image ** image,
     return cpl_error_get_code();
 
 }
-
+#if 0
+/* NOT USED! */
 /*---------------------------------------------------------------------------*/
 
 /*
@@ -541,8 +543,10 @@ irplib_bivector_gen_rect_poisson(const int *r, const int np, const int homog)
     }
     return list;
 }
+#endif
 
-
+#if 0
+/* Not used !! */
 /*---------------------------------------------------------------------------*/
 
 /*
@@ -596,8 +600,9 @@ xsh_detmon_retrieve_dark_params(const char *pipeline_name,
 
     return CPL_ERROR_NONE;
 }
-
-
+#endif
+#if 0
+/* NOT USED! */
 /*---------------------------------------------------------------------------*/
 
 /*
@@ -846,7 +851,7 @@ xsh_detmon_dark_save(const cpl_parameterlist * parlist,
     /*******************************/
 
     /* Get FITS header from reference file */
-    ref_frame = cpl_frameset_get_first(frameset);
+    ref_frame = cpl_frameset_get_position(frameset, 0);
     if((plist = cpl_propertylist_load(cpl_frame_get_filename(ref_frame),
                                       0)) == NULL) {
         cpl_msg_error(cpl_func, "getting header from reference frame");
@@ -902,7 +907,7 @@ xsh_detmon_dark_save(const cpl_parameterlist * parlist,
 
     return cpl_error_get_code();
 }
-
+#endif
 
 
 /**@}*/
