@@ -1832,7 +1832,7 @@ cpl_frameset*
 xsh_frameset_drl_frames(cpl_frameset* set);
 cpl_error_code
 xsh_frameset_merge(cpl_frameset * set1, cpl_frameset* set2);
-cpl_error_code xsh_ensure_raws_number_is_even(cpl_frameset* raws);
+cpl_frame* xsh_ensure_raws_number_is_even(cpl_frameset* raws);
 
 cpl_frameset *
 xsh_frameset_extract_pre(cpl_frameset * set, const char* prefix);
