@@ -1115,7 +1115,7 @@ xsh_follow_arclines( cpl_frame *pre_frame,
         else{
           double slope = 0.0, chisq = 0.0, xmin = 0.0, xmax = 0.0;
           double fwhm_center = 0.0;
-          double good_center;
+          double good_center = 0;
 
           /* Then fit tilt:
              Along the X axis, [xc-length,xc+length], detect
