@@ -625,7 +625,12 @@ xsh_localize_obj_auto( cpl_frame *merge_frame,
 
   nb_chunk = loc_obj_par->loc_chunk_nb-skip_chunk;
 
-  XSH_ASSURE_NOT_ILLEGAL(loc_obj_par->loc_deg_poly < nb_chunk);
+  XSH_ASSURE_NOT_ILLEGAL_MSG(loc_obj_par->loc_deg_poly < nb_chunk,
+		  "To fit a polynomial of deg n (loc_obj_par->loc_deg_poly) "\
+		  "you need at least n+1 points. This condition has failed "\
+		  "after clipping out other chunks not matching predefined criteria. "\
+		  "This can be due to the data (not well defined order trace) and/or "\
+		  "to a too high degree (localize-deg-lambda) of the polynomial fit");
 
   check( chunk_center_v = cpl_vector_wrap( 
       nb_chunk, chunk_center));
