@@ -533,7 +533,7 @@ xsh_utils_efficiency_internal(cpl_table* tbl_obj_spectrum,
 			      )
 {
 
-  const double TEL_AREA		= 51.2e4; /* collecting area in cm2 */
+  const double TEL_AREA		= 51.2e4;//49.8340828812e4;// /* collecting area in cm2 */
   double cdelta1 = 0;
   int i = 0;
   cpl_table* tbl_sel = NULL;
@@ -1172,7 +1172,7 @@ xsh_efficiency_compute(cpl_frame* frm_sci,
 }
 
 
-
+#if 0
 static double slaAirmas ( double zd )
 /*
 **  - - - - - - - - - -
@@ -1236,7 +1236,7 @@ static double slaAirmas ( double zd )
    return 1.0 + seczm1 * ( 0.9981833
                            - seczm1 * ( 0.002875 + 0.0008083 * seczm1 ) );
 }
-      
+#endif
 /*
   LST 
   =========================
