@@ -97,7 +97,7 @@ xsh_histogram(const cpl_table* data,
   int ntot=0;
   int i=0;
   int* phy=NULL;
-  double* pdt=NULL;
+  const double* pdt=NULL;
   /* double* phx=NULL; */
 
   double vtmp=0;
@@ -132,7 +132,7 @@ xsh_histogram(const cpl_table* data,
 
   phy=cpl_table_get_data_int(histo,"HY");
 
-  pdt=cpl_table_get_data_double(data,cname);
+  pdt=cpl_table_get_data_double_const(data,cname);
   //cpl_table_save(data, NULL, NULL, "histo_data.fits", CPL_IO_DEFAULT);
   for(i=0;i<nbins;i++) {
     cpl_table_set_double(histo,"HX",i,(double)i);
@@ -152,13 +152,8 @@ xsh_histogram(const cpl_table* data,
 
 
   return histo;
- cleanup:
-  xsh_free_table(&tmp_tbl1);
-  xsh_free_table(&tmp_tbl2);
 
 
-  return -1;
-
 }
 
 
